@@ -56,6 +56,11 @@ template<> inline long numeric_limits<long>::min() throw () {return LONG_MIN;}
 #endif // HAVE_LIMITS
 
 
+#ifndef HAVE_ABS_LONG
+// For compilers that feel abs(long) is ambiguous
+long abs(long n) { return (n >= 0) ? n : -n; }
+#endif // HAVE_ABS_LONG
+
 // Used for Windows DLL
 #ifndef PQXX_LIBEXPORT
 #define PQXX_LIBEXPORT
