@@ -51,6 +51,12 @@ int main(int, char *argv[])
       throw logic_error("Cursor reported size " + ToString(Cur.size()) + ", "
 	                "expected 0");
   }
+  catch (const sql_error &e)
+  {
+    cerr << "SQL error: " << e.what() << endl
+         << "Query was: '" << e.query() << "'" << endl;
+    return 1;
+  }
   catch (const exception &e)
   {
     // All exceptions thrown by libpqxx are derived from std::exception
